Skip to contents

Calculate drug prioritization scores based on the ratio of sensitive and resistant tumor cell populations identified by scPharmIdentify.

Usage

scPharmDr(object)

Arguments

object

A Seurat object after running scPharmIdentify.

Value

A data frame with the following columns:

DRUG_ID

GDSC drug identifier

DRUG_NAME

Drug name

SENSI_RATIO

Proportion of sensitive tumor cells

RESIS_RATIO

Proportion of resistant tumor cells

Dr

Drug prioritization score

Rank

Drug ranking (1 = best)

Details

The Dr score is calculated as: $$Dr = S \times (1 - R)$$ where S is the proportion of sensitive cells and R is the proportion of resistant cells among tumor cells. Higher scores indicate better drug candidates for the patient.

Examples

if (FALSE) { # \dontrun{
# After running scPharmIdentify
dr_scores <- scPharmDr(result)
head(dr_scores)
} # }