Skip to contents

Calculate drug side effect scores based on the sensitivity of adjacent (normal) cells to drugs. Higher scores indicate greater potential for off-target toxicity.

Usage

scPharmDse(object)

Arguments

object

A Seurat object after running scPharmIdentify with type="tissue".

Value

A data frame with the following columns:

DRUG_ID

GDSC drug identifier

DRUG_NAME

Drug name

Dse

Side effect score (0-1, higher = more side effects)

Details

The Dse score represents the proportion of adjacent (non-tumor) cells that are classified as sensitive to each drug. Drugs with high Dse scores may cause more side effects by affecting normal cells.

Examples

if (FALSE) { # \dontrun{
# After running scPharmIdentify with type="tissue"
dse_scores <- scPharmDse(result)
head(dse_scores)
} # }